@@ -180,4 +180,37 @@ def z_spread(clean_price: float,
             clean_price, yieldcurve, 
             ql_day_count[setting.day_count], 
             ql.Compounded, 
-            ql_frequency[setting.frequency])
\ No newline at end of file
+            ql_frequency[setting.frequency])
+
+
+def get_call_schedule(call_prices: List[CallabilityPrice]):
+    callability_schedule = ql.CallabilitySchedule()
+
+    for call_price in call_prices:
+        c_price  = ql.CallabilityPrice(call_price.price, call_price.price_type)
+        calldate = datestr_to_qldate(call_price.date)
+        callability_schedule.append(ql.Callability(c_price, 
+                                                    call_price.option_type,
+                                                    calldate)
+                                    )
+    return callability_schedule
+
+
+def get_qlcallablebond(bond_info: FixedRateBond,
+                        bond_setting: BondSetting,
+                        bond_schedule: ql.QuantLib.Schedule,
+                        coupons: List[float],
+                        call_schedule: ql.QuantLib.CallabilitySchedule,
+                        settlement_days: int = 0):
+    callbond = ql.CallableFixedRateBond(
+                settlement_days, 
+                bond_info.face_value,
+                bond_schedule, 
+                coupons, 
+                ql_day_count[bond_setting.day_count],
+                ql_business_day[bond_setting.business_day], 
+                bond_info.face_value, 
+                datestr_to_qldate(bond_info.issue_date),
+                call_schedule)
+    return callbond
+
