@@ -178,7 +178,7 @@ class FixedRateBond(BaseModel):
     issue_date: Optional[str] = None
     maturity: str
     settings: BondSetting
-    face_value: float
+    face_value: Optional[float] = 100.00
     coupon: float 
     structure: Optional[List[Structure]] = None
 
@@ -243,6 +243,7 @@ class CashFlowInspector(BaseModel):
 
 class BondRisk(BaseModel):
     accrued: Optional[float] = None
+    ytm: Optional[float] = None
     clean_price: Optional[float] = None
     bps: Optional[float] = None
     duration: Optional[float] = None
@@ -256,6 +257,7 @@ class BondRisk2(BondRisk):
     value: Optional[float] = None
     value_after_shift: Optional[float] = None
 
+
 class CashFlow(BaseModel):
     date: str 
     amount: float
@@ -274,4 +276,12 @@ class CashFlow(BaseModel):
             anumber = float(v)
         except:
             raise ValueError
-        return  v
\ No newline at end of file
+        return  v
+
+
+class CallabilityPrice(BaseModel):
+    price_type: BondPriceType = BondPriceType.clean
+    price: float
+    date: str
+    option_type: OptionType = OptionType.calloption
+
