@@ -4,7 +4,9 @@ from .ql_conventions import *
 import QuantLib as ql
 
 
-def create_calendar(description: str, holidays:List[Holiday] = [], mycal = None):
+def create_calendar(description: Optional[str], 
+                    holidays:List[Holiday] = [], 
+                    mycal = None):
 
     cal = ql.BespokeCalendar(description)
     qldates = [datestr_to_qldate(holiday.date) for holiday in holidays]
@@ -31,7 +33,6 @@ def get_qlPeriod(tenor:str):
     return  ql.Period(number, ql_tenor[prd])
 
 
-
 def qlSchedule(issue_date: str, 
             maturity: str, 
             period: ql.QuantLib.Period, 
